@@ -1100,10 +1100,10 @@ class Instance(proto.Message):
 
     class AvailabilityType(proto.Enum):
         r"""The Availability type of an instance. Potential values:
-        <br><b>ZONAL</b>: The instance serves data from only one zone.
-        Outages in that zone affect instance availability.
-        <br><b>REGIONAL</b>: The instance can serve data from more
-        than one zone   in a region (it is highly available).
+        - ZONAL: The instance serves data from only one zone. Outages in
+        that zone affect instance availability.
+        - REGIONAL: The instance can serve data from more than one zone
+        in a region (it is highly available).
 
         Values:
             AVAILABILITY_TYPE_UNSPECIFIED (0):
